# annorepo-client

A Python client for accessing an [AnnoRepo](https://github.com/brambg/annorepo) server

## installing

### using poetry

```
poetry add annorepo-client
```

### using pip

```
pip install annorepo-client
```



## contributing

See [CONTRIBUTING](CONTRIBUTING.md)